# vantage-client
Vantage API

This Python package is automatically generated by the [Swagger Codegen](https://github.com/swagger-api/swagger-codegen) project:

- API version: 1.0.0
- Package version: 0.0.2
- Build package: io.swagger.codegen.languages.PythonClientCodegen
For more information, please visit [https://www.vantage.sh](https://www.vantage.sh)

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

```sh
pip install vantage-client
```

Then import the package:
```python
import vantage 
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import vantage
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function
import time
import vantage
from vantage.rest import ApiException
from pprint import pprint

# Configure OAuth2 access token for authorization: oauth2
configuration = vantage.Configuration()
configuration.access_token = 'YOUR_ACCESS_TOKEN'

# create an instance of the API class
api_instance = vantage.PingApi(vantage.ApiClient(configuration))

try:
    api_response = api_instance.ping()
    pprint(api_response)
except ApiException as e:
    print("Exception when calling PingApi->ping: %s\n" % e)

```

## Documentation for API Endpoints

All URIs are relative to *https://api.vantage.sh*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*PingApi* | [**ping**](docs/PingApi.md#ping) | **GET** /v1/ping | 
*PricesApi* | [**get_price**](docs/PricesApi.md#get_price) | **GET** /v1/products/{product_id}/prices/{id} | 
*PricesApi* | [**get_prices**](docs/PricesApi.md#get_prices) | **GET** /v1/products/{product_id}/prices | 
*PricesApi* | [**get_product**](docs/PricesApi.md#get_product) | **GET** /v1/products/{id} | 
*PricesApi* | [**get_products**](docs/PricesApi.md#get_products) | **GET** /v1/products | 
*PricesApi* | [**get_providers**](docs/PricesApi.md#get_providers) | **GET** /v1/providers | 
*PricesApi* | [**get_services**](docs/PricesApi.md#get_services) | **GET** /v1/services | 


## Documentation For Models

 - [Price](docs/Price.md)
 - [Prices](docs/Prices.md)
 - [Product](docs/Product.md)
 - [Products](docs/Products.md)
 - [Provider](docs/Provider.md)
 - [Providers](docs/Providers.md)
 - [Service](docs/Service.md)
 - [Services](docs/Services.md)


## Documentation For Authorization


## oauth2

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**: 
- **Scopes**: 
 - **read**: Grants read access


## Author

support@vantage.sh

